@@ -15,12 +15,14 @@ gi.require_version("Gst", "1.0")
 gi.require_version("GstAudio", "1.0")
 gi.require_version("GstPbutils", "1.0")
 gi.require_version("TotemPlParser", "1.0")
-from gi.repository import Gtk, Gio, GLib, Gdk, Gst
+from gi.repository import Gtk, Gio, GLib, Gdk, Gst, GstPbutils
 Gst.init(None)
+GstPbutils.pb_utils_init()
 
 from threading import current_thread
 from pickle import dump
 from signal import signal, SIGINT, SIGTERM
+import gc
 
 
 try:
@@ -152,6 +154,8 @@ class Application(Gtk.Application, ApplicationActions):
         self.register(None)
         if self.get_is_remote():
             Gdk.notify_startup_complete()
+        if GLib.environ_getenv(GLib.get_environ(), "DEBUG_LEAK") is not None:
+            gc.set_debug(gc.DEBUG_LEAK)
 
     def init(self):
         """
@@ -269,6 +273,11 @@ class Application(Gtk.Application, ApplicationActions):
         for scrobbler in self.scrobblers:
             scrobbler.save()
         Gio.Application.quit(self)
+        if GLib.environ_getenv(GLib.get_environ(), "DEBUG_LEAK") is not None:
+            gc.collect()
+            for x in gc.garbage:
+                s = str(x)
+                print(type(x), "\n  ", s)
 
     def load_listenbrainz(self):
         """
@@ -397,7 +406,7 @@ class Application(Gtk.Application, ApplicationActions):
             # Save albums context
             try:
                 with open(LOLLYPOP_DATA_PATH + "/Albums.bin", "wb") as f:
-                    dump(list(self.player.albums), f)
+                    dump(self.player.albums, f)
             except Exception as e:
                 Logger.error("Application::__save_state(): %s" % e)
         dump(track_id, open(LOLLYPOP_DATA_PATH + "/track_id.bin", "wb"))
