@@ -10,13 +10,15 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, Gio
+from gi.repository import Gio, GObject, Gtk
 
 from gettext import gettext as _
 
 from lollypop.logger import Logger
+from lollypop.utils import emit_signal
 from lollypop.widgets_artwork import ArtworkSearchWidget, ArtworkSearchChild
-from lollypop.define import App, Type
+from lollypop.define import App, Type, ViewType, MARGIN, MARGIN_SMALL
+from lollypop.define import ArtBehaviour, ArtSize
 
 
 class AlbumArtworkSearchWidget(ArtworkSearchWidget):
@@ -24,13 +26,51 @@ class AlbumArtworkSearchWidget(ArtworkSearchWidget):
         Search for album artwork
     """
 
-    def __init__(self, album):
+    __gsignals__ = {
+        "hidden": (GObject.SignalFlags.RUN_FIRST, None, (bool,)),
+    }
+
+    def __init__(self, album, view_type):
         """
             Init search
             @param album as Album
+            @param view_type as ViewType
         """
-        ArtworkSearchWidget.__init__(self)
+        ArtworkSearchWidget.__init__(self, view_type)
         self.__album = album
+        if view_type & ViewType.ADAPTIVE:
+            self.set_row_spacing(MARGIN)
+            self.set_margin_start(MARGIN_SMALL)
+            self.set_margin_end(MARGIN_SMALL)
+            self.set_margin_top(MARGIN)
+            self.set_margin_bottom(MARGIN)
+            button = Gtk.ModelButton.new()
+            button.set_alignment(0, 0.5)
+            button.connect("clicked",
+                           lambda x: emit_signal(self, "hidden", True))
+            button.show()
+            label = Gtk.Label.new()
+            label.show()
+            self.__artwork = Gtk.Image.new()
+            name = "<span alpha='40000'>%s</span>" % album.name
+            App().art_helper.set_album_artwork(
+                                            album,
+                                            ArtSize.SMALL,
+                                            ArtSize.SMALL,
+                                            self.__artwork.get_scale_factor(),
+                                            ArtBehaviour.CACHE |
+                                            ArtBehaviour.CROP_SQUARE,
+                                            self.__on_album_artwork)
+            self.__artwork.show()
+            label.set_markup(name)
+            grid = Gtk.Grid()
+            grid.set_column_spacing(MARGIN)
+            grid.add(self.__artwork)
+            grid.add(label)
+            button.set_image(grid)
+            button.get_style_context().add_class("padding")
+            self.insert_row(0)
+            self.attach(button, 0, 0, 1, 1)
 
     def populate(self):
         """
@@ -42,7 +82,7 @@ class AlbumArtworkSearchWidget(ArtworkSearchWidget):
             uris = App().art.get_album_artworks(self.__album)
             # Direct load, not using loopback because not many items
             for uri in uris:
-                child = ArtworkSearchChild(_("Local"))
+                child = ArtworkSearchChild(_("Local"), self._view_type)
                 child.show()
                 f = Gio.File.new_for_uri(uri)
                 (status, content, tag) = f.load_contents()
@@ -56,39 +96,20 @@ class AlbumArtworkSearchWidget(ArtworkSearchWidget):
 #######################
 # PROTECTED           #
 #######################
-    def _on_button_clicked(self, button):
+    def _save_from_filename(self, filename):
         """
-            Show file chooser
+            Save filename as album artwork
             @param button as Gtk.button
         """
-        dialog = Gtk.FileChooserDialog()
-        dialog.add_buttons(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
-        dialog.add_buttons(Gtk.STOCK_OPEN, Gtk.ResponseType.OK)
-        dialog.set_transient_for(App().window)
-        self._close_popover()
-        response = dialog.run()
-        if response == Gtk.ResponseType.OK:
-            try:
-                f = Gio.File.new_for_path(dialog.get_filename())
-                (status, data, tag) = f.load_contents()
-                if status:
-                    App().art.save_album_artwork(data, self.__album)
-                self._streams = {}
-            except Exception as e:
-                Logger.error(
-                    "AlbumArtworkSearchWidget::_on_button_clicked(): %s" % e)
-        dialog.destroy()
-
-    def _on_reset_confirm(self, button):
-        """
-            Reset artwork
-            @param button as Gtk.Button
-        """
-        ArtworkSearchWidget._on_reset_confirm(self, button)
-        App().art.remove_album_artwork(self.__album)
-        App().art.save_album_artwork(None, self.__album)
-        App().art.clean_album_cache(self.__album)
-        App().art.emit("album-artwork-changed", self.__album.id)
+        try:
+            f = Gio.File.new_for_path(filename)
+            (status, data, tag) = f.load_contents()
+            if status:
+                App().task_helper.run(App().art.save_album_artwork,
+                                      data, self.__album)
+        except Exception as e:
+            Logger.error(
+                "AlbumArtworkSearchWidget::_save_from_filename(): %s" % e)
 
     def _get_current_search(self):
         """
@@ -131,10 +152,25 @@ class AlbumArtworkSearchWidget(ArtworkSearchWidget):
         """
         try:
             if isinstance(child, ArtworkSearchChild):
-                self._close_popover()
-                App().art.save_album_artwork(child.bytes, self.__album)
-                self._streams = {}
+                App().task_helper.run(App().art.save_album_artwork,
+                                      child.bytes, self.__album)
             else:
-                ArtworkSearchWidget._on_activate(self, flowbox, child)
+                App().art.remove_album_artwork(self.__album)
+                App().art.save_album_artwork(None, self.__album)
+                App().art.clean_album_cache(self.__album)
+                emit_signal(App().art, "album-artwork-changed",
+                            self.__album.id)
+            emit_signal(self, "hidden", True)
         except Exception as e:
             Logger.error("AlbumArtworkSearchWidget::_on_activate(): %s", e)
+
+    def __on_album_artwork(self, surface):
+        """
+            Set album artwork
+            @param surface as str
+        """
+        if surface is None:
+            self.__artwork.set_from_icon_name("folder-music-symbolic",
+                                              Gtk.IconSize.BUTTON)
+        else:
+            self.__artwork.set_from_surface(surface)
